@@ -52,6 +52,7 @@ const KeyListEntry desktop_key_list[] =
   { "/apps/metacity/global_keybindings/panel_main_menu", ALWAYS_VISIBLE, 0 },
   { "/apps/metacity/global_keybindings/run_command_screenshot", ALWAYS_VISIBLE, 0 },
   { "/apps/metacity/global_keybindings/run_command_window_screenshot", ALWAYS_VISIBLE, 0 },
+  { "/apps/metacity/global_keybindings/run_command_terminal", ALWAYS_VISIBLE, 0 },
 #ifdef USE_FBLEVEL
   { "/apps/gnome_settings_daemon/keybindings/brightness_down", ALWAYS_VISIBLE, 0 },
   { "/apps/gnome_settings_daemon/keybindings/brightness_up", ALWAYS_VISIBLE, 0 },
@@ -769,6 +770,21 @@ real_start_editing_cb (IdleData *idle_data)
   return FALSE;
 }
 
+static gboolean
+start_editing_kb_cb (GtkTreeView *treeview, 
+			  GtkTreePath *path, 
+			  GtkTreeViewColumn *column,
+			  gpointer user_data)
+{
+  gtk_widget_grab_focus (GTK_WIDGET (treeview));
+  gtk_tree_view_set_cursor (treeview,
+			    path,
+			    gtk_tree_view_get_column (treeview, 1),
+			    TRUE);
+
+  return FALSE;
+}
+
 static gboolean
 start_editing_cb (GtkTreeView    *tree_view,
 		  GdkEventButton *event,
@@ -826,6 +842,9 @@ setup_dialog (GladeXML *dialog)
   g_signal_connect (GTK_TREE_VIEW (WID ("shortcut_treeview")),
 		    "button_press_event",
 		    G_CALLBACK (start_editing_cb), dialog),
+	g_signal_connect (GTK_TREE_VIEW (WID ("shortcut_treeview")),
+	      "row-activated",
+		    G_CALLBACK (start_editing_kb_cb), dialog),
 		    
   column = gtk_tree_view_column_new_with_attributes (_("Action"),
 						     gtk_cell_renderer_text_new (),
